baseObjects.ResultSetStore

|  | ## Cheshire3 Object Model: Class ResultSetStore

Module baseObjects :: Class ResultSetStore

## Class ResultSetStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
                               ResultSetStore

Known Subclasses:
  resultSetStore.SimpleResultSetStore

A persistent storage mechanism for result sets.
Instance Methods

create_resultSet(self, session, rset=None)
delete_resultSet(self, session, req)
fetch_resultSet(self, session, req)
fetch_resultSetList(self, session, req)
store_resultSet(self, session, req)
Inherited from `ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### create_resultSet(self, session, rset=None) | source code

### delete_resultSet(self, session, req) | source code

### fetch_resultSet(self, session, req) | source code

### fetch_resultSetList(self, session, req) | source code

### store_resultSet(self, session, req) | source code